DysymtabCommand

Struct DysymtabCommand 

#[repr(C)]
pub struct DysymtabCommand<E: Endian> {
Show 20 fields pub cmd: U32<E>, pub cmdsize: U32<E>, pub ilocalsym: U32<E>, pub nlocalsym: U32<E>, pub iextdefsym: U32<E>, pub nextdefsym: U32<E>, pub iundefsym: U32<E>, pub nundefsym: U32<E>, pub tocoff: U32<E>, pub ntoc: U32<E>, pub modtaboff: U32<E>, pub nmodtab: U32<E>, pub extrefsymoff: U32<E>, pub nextrefsyms: U32<E>, pub indirectsymoff: U32<E>, pub nindirectsyms: U32<E>, pub extreloff: U32<E>, pub nextrel: U32<E>, pub locreloff: U32<E>, pub nlocrel: U32<E>,
}

Fields

cmd: U32<E>

LC_DYSYMTAB

cmdsize: U32<E>

sizeof(struct DysymtabCommand)

ilocalsym: U32<E>

index to local symbols

nlocalsym: U32<E>

number of local symbols

iextdefsym: U32<E>

index to externally defined symbols

nextdefsym: U32<E>

number of externally defined symbols

iundefsym: U32<E>

index to undefined symbols

nundefsym: U32<E>

number of undefined symbols

tocoff: U32<E>

file offset to table of contents

ntoc: U32<E>

number of entries in table of contents

modtaboff: U32<E>

file offset to module table

nmodtab: U32<E>

number of module table entries

extrefsymoff: U32<E>

offset to referenced symbol table

nextrefsyms: U32<E>

number of referenced symbol table entries

indirectsymoff: U32<E>

file offset to the indirect symbol table

nindirectsyms: U32<E>

number of indirect symbol table entries

extreloff: U32<E>

offset to external relocation entries

nextrel: U32<E>

number of external relocation entries

locreloff: U32<E>

offset to local relocation entries

nlocrel: U32<E>

number of local relocation entries

Implementations

Source

impl<E: Endian> DysymtabCommand<E>

pub fn indirect_symbols<'data, R: ReadRef<'data>>( &self, endian: E, data: R, ) -> Result<&'data [U32<E>]>

Return the table of indirect symbol indexes.

Entries in this table are referenced by the reserved1 field in sections that contain symbol pointers or stubs.

Each entry is an index into the symbol table.